#!/bin/ksh
[[ $TRACE_VPM -ge 1 ]] &&  set -x
#######################################################################
#                                                                     #
#        Class          :       build Tools                           #
#                                                                     #
#        Creator        :       ABE                                   #
#                                                                     #
# (c) Copyright Dassault Systemes 2006                                #
#######################################################################

# Log file
# --------

LOGFILE=$PWD/libLV0XUSR.out
rm -f $LOGFILE
touch $LOGFILE
if [ $? -ne 0 ]
then
  echo "Warning:"
  echo "  unable to open log file: "$LOGFILE
  exit 1
fi

# init compiler and link edit options
#####################################
. lkopt

echo "\n\n"
echo "\t###################################################################"
echo "\t#								  #"
echo "\t#      Installation shell for VPM1 user exits: CATDMUsrMethod     #"
echo "\t#								  #"
echo "\t###################################################################"
echo "\n\n"


Usage()
{
echo "\n\nUsage:"
echo "  makeLV0XUSR source_directory "
echo "\nWhere:"
echo "  source_directory : directory where ALL the source code for"
echo "                     the user exit is located:\n"
echo "                     - CATDMUsrMethod.cpp "
echo "                     - other .cpp and .h files created for the"
echo "                       user exit."
echo "\n The library libLV0XUSR will be created in the current directory."
echo " Therefore, you must have write access on that directory."
echo "\n\n"
rm $LOGFILE
exit 1
}

EndWithError()
{
echo "\n\n"
echo "\t*******************************************************"
echo "\t*                                                     *"
echo "\t* CATDMUsrMethod user exit Installation error        *"
echo "\t* Consult file $LOGFILE                               *"
echo "\t*                                                     *"
echo "\t*******************************************************"
echo "\n\n"
exit 1
}

############
#   MAIN   #
############

# Check arguments
# ---------------

if [ $# -ne 1 ] ||  [ $1 = "-h" ]
then
  Usage
fi

# Operating system
# ----------------

TypeHost=$(uname -s)
if [ $TypeHost = "AIX" ]
then
    VERSIONAIX=`uname -v`
    if [ $VERSIONAIX = 4 ] ;  then
        TypeHost=$TypeHost'v4'
    fi
    if [ $VERSIONAIX = 5 ] ;  then
        TypeHost=$TypeHost'v5'
    fi
fi

# Compiler options
# ----------------
SMP_DIR="$VPM/code/sample"

if [ $# -gt 0 ]
then
    SRC_DIR=$1
else
    SRC_DIR=$SMP_DIR
fi

if [ ! -d $SRC_DIR ] || [ ! -f $SRC_DIR/"CATDMUsrMethod.cpp" ]
then
    echo "Error:"
    echo "  $SRC_DIR is not a valid directory!!\n\n"
    exit
fi
    
optI="-I$SMP_DIR"
if [ $SRC_DIR != $SMP_DIR ]
then 
    optI="$optI -I$SRC_DIR"
fi
#JIC
optI="$optI -I$VPM/PublicInterfaces -I$CATIA/code/include -I$VPM/reffiles/source/include"
optI="$optI -I$ROOT_CODE/ISPPS9VPM/include"

# Object compilation
# ------------------
echo "\t - Building libLV0XUSR ................. \n"

for CppName in $($(which ls) -d $SRC_DIR/*.cpp)
do
    echo "\t\t - Compiling $CppName .................. \c"
    if [ $TypeHost = AIXv5  ] ;  then
        AWK="awk"
	$CAT_CPP -c $CAT_CPP_OPT $optI $CppName >> $LOGFILE 2>> $LOGFILE
         rc=$?
    elif [ $TypeHost = HP-UX ]; then
        AWK="awk"
      $CAT_CPP -c $CAT_CPP_OPT $optI $CppName  >> $LOGFILE 2>> $LOGFILE
         rc=$?
    elif [ $TypeHost = SunOS ]; then
        AWK="nawk"
		$CAT_CPP -c $CAT_CPP_OPT $optI $CppName >> $LOGFILE 2>> $LOGFILE

        rm -f $TMP
    fi
    if [[ $rc -ne 0 ]]
    then
	echo "Ko\n"
	EndWithError
    else
	echo "Ok\n"
        OBJECTS="$OBJECTS $PWD/$(echo ${CppName%.cpp}|$AWK -F/ '{print $NF}' -).o"
    fi
done

echo "\t\t - Linking ............................... \c"


LIBLV0="libLV0XUSR"

SH_LIBPATH="-L$VPM/code/bin"
if [ $TypeHost = AIX -o $TypeHost = AIXv4 -o $TypeHost = AIXv5 ]; then
    SH_LIBPATH="$SH_LIBPATH -L$CATIA/code/lib -L$ROOT_CODE/PTF15/steplib/AIX"
    SH_LIB="-lgeo -lISPPS9VPM"
	$CAT_LK $CAT_LK_OPT -o $PWD/$LIBLV0.a \
        -bnolibpath $SH_LIBPATH -bnolibpath $SH_LIB $OBJECTS  >> $LOGFILE 2>> $LOGFILE
	
elif [ $TypeHost = HP-UX ]; then
    OBJECTS="$OBJECTS $CATIA/code/lib/libgeo.a $ROOT_CODE/PTF15/steplib/HP-UX/libISPPS9VPM.sl"
    $CAT_LK  $CAT_LK_OPT -Wl,+h,lib$LIBLV0.sl -o $PWD/$LIBLV0.sl \
        $SH_LIBPATH $SH_LIB $OBJECTS  >> $LOGFILE 2>> $LOGFILE
                
elif [ $TypeHost = SunOS ]; then
    OBJECTS="$OBJECTS $CATIA/code/lib/libgeo.a $ROOT_CODE/PTF15/steplib/SunOS/libISPPS9VPM.so"
    $CAT_LK  $CAT_LK_OPT2 \
    -L/lib -L/usr/lib -lM77 -lF77 -lfsu -lsunmath -lm -lC \
    -o $PWD/$LIBLV0.so   $SH_LIBPATH $SH_LIB $OBJECTS   >> $LOGFILE 2>> $LOGFILE
fi

if [ $? -ne 0 ]
then
    echo "Ko\n"
    EndWithError
else
    echo "Ok\n"
fi

rm *.o
#rm $LOGFILE

echo "\n\n"
echo "\t*********************************"
echo "\t*                               *"
echo "\t* libLV0XUSR successfully built *"
echo "\t*                               *"
echo "\t*********************************"
echo "\n\n"

if [ $TypeHost = AIX ]
then
	SHLIBPATHNAME=LIBPATH
	SHLIBNAME=$LIBLV0.a
elif [ $TypeHost = HP-UX ]
then
	SHLIBPATHNAME=SHLIB_PATH
	SHLIBNAME=$LIBLV0.sl
elif [ $TypeHost = SunOS ]
then
	SHLIBPATHNAME=LD_LIBRARY_PATH
	SHLIBNAME=$LIBLV0.so
fi
echo "\n"
echo "Warning:"
echo "-------\n"
echo "So that the VPM takes into account the library you have just generated,"
echo "you must modify the place where it will look for this library.\n"
echo "In order to be sure you are using the right library each time you"
echo "work with VPM, you should add these lines to your \$CAT_ENV file:\n"
echo "        STEPLIB=$PWD:\$STEPLIB"
echo "        export STEPLIB"
echo "        $SHLIBPATHNAME=$PWD:\$$SHLIBPATHNAME"
echo "        export $SHLIBPATHNAME\n"
echo "At any time, you can check the library you are referencing by typing:\n"
echo "        catpath STEPLIB $SHLIBNAME\n"
return 0

